@@ -6,18 +6,18 @@ use 5.010;
 use strict;
 use warnings;
 
-use Sub::Spec::Utils; # tmp, for _parse_schema
+use Data::Sah::Util;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(spec_to_usage);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %SPEC;
 
 sub _parse_schema {
-    Sub::Spec::Utils::_parse_schema(@_);
+    Data::Sah::Util::_parse_schema(@_);
 }
 
 $SPEC{spec_to_usage} = {
@@ -188,7 +188,7 @@ Sub::Spec::To::Text::Usage - Generate usage/help message from sub spec
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
